File abstractions for Oicana, a set of libraries and tools for document templating with Typst.
Oicana templates are mostly used in their packaged form as a zip file containing the complete Typst project. For development and testing, they can also be accessed as a directory in a file system, or as a map of Strings.
Modules
Traits
- Template
Files - Access files in an Oicana template.